clixx.printers
==============

.. currentmodule:: clixx.printers

Typing
------

.. autoclass:: Printer
    :members:
    :show-inheritance:

.. autoclass:: SuperPrinter
    :members:
    :show-inheritance:

.. autodata:: PrinterFactory

.. autodata:: SuperPrinterFactory

Classes
-------

.. autoclass:: _PrinterHelper
    :members:
    :special-members: __enter__, __exit__
    :show-inheritance:

.. autoclass:: PrinterHelper
    :members:
    :show-inheritance:

.. autoclass:: SuperPrinterHelper
    :members:
    :show-inheritance:
